@@ -317,9 +317,15 @@ def AttendImport(request, day, month, year):
 	if request.method == 'POST':
 		csv_file = request.FILES['fupload']
 		if not csv_file.name.endswith('.csv'):
-			messages.error(request, f'The uploaded file should in CSV format.')
+			messages.error(request, 'The uploaded file should be in CSV format.')
 
-		data_set = pd.read_csv(csv_file)
+		# Convert bytes to string
+		csv_data = csv_file.read().decode('utf-8')
+
+		# Use StringIO to create a file-like object
+		csv_file_obj = io.StringIO(csv_data)
+
+		data_set = pd.read_csv(csv_file_obj, delimiter=',|;', engine='python')
 		df = pd.DataFrame(data_set, columns=['PIN', 'Nama Karyawan', 'Tanggal', 'Jam', 'Mode'])
 		df = df.assign(AbsenceIn=df['Mode'] == 'Scan Masuk')
 		df = df.assign(AbsenceOut=df['Mode'] == 'Scan Keluar')
